Documentation
¶
Overview ¶
Package signer provides a common interface for signing
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Signature ¶
Signature is an ecdsa signature interface.
func DecodeSignature ¶ added in v0.0.37
DecodeSignature decodes a signature.
func NewSignature ¶
NewSignature creates a new signature using the v, r, and s params.
type Signer ¶
type Signer interface {
// SignMessage signs a message
SignMessage(ctx context.Context, message []byte, hash bool) (Signature, error)
// GetTransactor gets the transactor for a tx manager.
// TODO: this doesn't support pre-london txes yet
GetTransactor(ctx context.Context, chainID *big.Int) (*bind.TransactOpts, error)
// Address gets the address of the address of the signer
Address() ethCommon.Address
// PrivKey gets the libp2p priv key.
// TODO: we should consider abstracting this otu of ethergo. It's an odd, synapse specific dependency
// TODO: this method also needs a cross-implementation test similar to RunOnAllDBs()
// that does not fit into what etherog is supposed to be.
PrivKey() libp2p.PrivKey
}
Signer provides a common interface for signing/transacting.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package awssigner contains a new signer that uses aws-kms as an hsm
|
Package awssigner contains a new signer that uses aws-kms as an hsm |
|
kmsmock
Package kmsmock sets up a mock kms server that is used for testing our kms driver TODO: we should consider moving this to a common testutils/mocking folder or something internal to avoid exporting
|
Package kmsmock sets up a mock kms server that is used for testing our kms driver TODO: we should consider moving this to a common testutils/mocking folder or something internal to avoid exporting |
|
kmsmock/internal
Package internal contains modules exported from local-kms in order to avoid rewriting code
|
Package internal contains modules exported from local-kms in order to avoid rewriting code |
|
Package gcpsigner utilizes the Key Management Service (KMS) from the Google Cloud Platform (GCP).
|
Package gcpsigner utilizes the Key Management Service (KMS) from the Google Cloud Platform (GCP). |
|
gcpmock
Package gcpmock provides a mock client for testing purposes.
|
Package gcpmock provides a mock client for testing purposes. |
|
Package localsigner is a local signer
|
Package localsigner is a local signer |
Click to show internal directories.
Click to hide internal directories.